window.Gleam.initSearch([{"doc":"spectator","title":"spectator","content":"## &lt;img width=16 src=&quot;https://raw.githubusercontent.com/JonasGruenwald/spectator/main/priv/lucy_spectator.svg&quot;&gt; Spectator\n[![Package Version](https://img.shields.io/hexpm/v/spectator)](https://hex.pm/packages/spectator)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/spectator/)\n\nSpectator is a BEAM observer tool written in Gleam, that plays well with gleam_otp processes.\n\n![](https://raw.githubusercontent.com/JonasGruenwald/spectator/refs/heads/main/priv/screenshot.png)\n\n## Features\n\nThis is a work in progress, so far it has the following features:\n\n- Show processes in a sortable table\n- Tag individual processes for easy identification\n- Show process details\n- Show OTP process state\n- Suspend / resume OTP processes\n- List ETS tables\n- View content of ETS tables\n- List of active ports\n- Clickable links between resources\n- Dashboard with basic statistics\n- Inspect other BEAM nodes\n\n## Installation\n\n```sh\ngleam add spectator\n```\n\n## Usage\n\n&gt; 🦔 **Please be aware spectator is still new, and a work in progress, reliability is not guaranteed, use at your own peril!**\n\nCall `spectator.start()` in your application, to start the spectator service and WebUI.\n\nIn order to make it easier to identify your Gleam processes in the process list, you can tag them with a friendly name with `spectator.tag`, `spectator.tag_subject` or `spectator.tag_result` **after** starting the spectator service.\n\n## Example\n\n```gleam\nimport gleam/erlang/process\nimport spectator\nimport utils/pantry\n\npub fn main() {\n  // Start the spectator service\n  let assert Ok(_) = spectator.start()\n\n  // Start an OTP actor\n  let assert Ok(sub) = pantry.new()\n\n  // Tag the actor with a name for easier identification in the spectator UI\n  // Note: this only works because we called spectator.start before!\n  sub\n  |&gt; spectator.tag_subject(&quot;Pantry Actor&quot;)\n\n  // Add some state to the actor\n  pantry.add_item(sub, &quot;This actor has some state&quot;)\n  pantry.add_item(sub, &quot;Another item in the state of this actor&quot;)\n  pantry.add_item(sub, &quot;And some more state I&#39;ve put into this demo actor&quot;)\n\n  // Sleep on the main process so the program doesn&#39;t exit\n  process.sleep_forever()\n}\n```\n\n## Considerations\n\nPlease be aware of the following implications of running spectator:\n\n* **Spectator may slow down your system**  \n  All displayed processes are probed in the configured interval using Erlang&#39;s `process_info/2` function which puts a temporary lock on the process being infoed. If the process is handling a lot of messages, this may have performance implications for the system\n* **Spectator will send system messages to selected processes**  \n  In order to get a selected processes OTP state, spectator needs to send it system messages. If you select a process that is not handling these messages properly, spectator may fill up its message queue, as it is sending a new message every tick in the configured interval. If the processes message queue is over a certain size, spectator will stop sending new messages, however the process may never handle the already queued up messages\n* **Spectator will create atoms dynamically**  \n  When you choose to connect to other Erlang nodes, spectator needs to convert the node name and cookie you provide into atoms. Therefore it is possible to exhaust the memory of the BEAM instance running spectator using its user interface, as atoms are never garbage collected.\n\n\n----\n\nFurther documentation can be found at &lt;https://hexdocs.pm/spectator&gt;.\n","url":"index.html"},{"doc":"spectator","title":"main","content":"pub fn main() -&gt; Nil\n Entrypoint for running spectator from the command line.\n This will start the spectator application on port 3000 and never return.\nSynonyms:\nspectator.main\nspectator main","url":"spectator.html#main"},{"doc":"spectator","title":"start","content":"pub fn start() -&gt; Result(Pid, Dynamic)\n Start the spectator application on port 3000\nSynonyms:\nspectator.start\nspectator start","url":"spectator.html#start"},{"doc":"spectator","title":"start_on","content":"pub fn start_on(port: Int) -&gt; Result(Pid, Dynamic)\n\nSynonyms:\nspectator.start_on\nspectator start_on","url":"spectator.html#start_on"},{"doc":"spectator","title":"tag","content":"pub fn tag(pid: Pid, name: String) -&gt; Pid\n Tag a process given by PID with a name for easier identification in the spectator UI.\n You must call `start` before calling this function.\nSynonyms:\nspectator.tag\nspectator tag","url":"spectator.html#tag"},{"doc":"spectator","title":"tag_result","content":"pub fn tag_result(\n  result: Result(Subject(a), b),\n  name: String,\n) -&gt; Result(Subject(a), b)\n Tag a process given by subject result with a name for easier identification in the spectator UI.\n You must call `start` before calling this function.\nSynonyms:\nspectator.tag_result\nspectator tag_result","url":"spectator.html#tag_result"},{"doc":"spectator","title":"tag_subject","content":"pub fn tag_subject(\n  subject sub: Subject(a),\n  name name: String,\n) -&gt; Subject(a)\n Tag a process given by subject with a name for easier identification in the spectator UI.\n You must call `start` before calling this function.\nSynonyms:\nspectator.tag_subject\nspectator tag_subject","url":"spectator.html#tag_subject"},{"doc":"spectator","title":"spectator","content":"","url":"spectator.html"}]);